#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-test-utils
version:              2.3.0.0
visibility:           public
id:                   hls-test-utils-2.3.0.0-7VZIh0u74hWJFa94h5swSw
key:                  hls-test-utils-2.3.0.0-7VZIh0u74hWJFa94h5swSw
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Utilities used in the tests of Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  6e109aef2749595cd4dd99eb31854aff
exposed:              True
exposed-modules:      Test.Hls Test.Hls.FileSystem Test.Hls.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-test-utils
hs-libraries:         HShls-test-utils-2.3.0.0-7VZIh0u74hWJFa94h5swSw
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z
    async-2.2.6-ClOW2oFWjQTDZxVKjsrmlu base-4.18.2.1
    blaze-markup-0.8.3.0-H0aLsJdkrRa2dxgQ4kTQHF bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    directory-1.3.8.5 extra-1.7.16-aWEq6cZZ289lIc6yxljo5
    filepath-1.4.300.1 ghcide-2.3.0.0-JSGU2hqwpKP2T9zGvf4q95
    hls-graph-2.3.0.0-9sfhFhb8hW17ubYRR2RsWN
    hls-plugin-api-2.3.0.0-4CgmjbnqzKN1c7iCNmzWCS
    lens-5.3.5-JKPJsUIkx0YEZ4W3JntdKw
    lsp-2.2.0.0-AMvH8uI6CvNFs6ZEiC2ocP
    lsp-test-0.16.0.0-JhAqJZHUBLa6rYOpJRvkVO
    lsp-types-2.0.2.0-FxqOKdDzvom3LxZERPn3Y4
    row-types-1.0.1.2-7y1Qreup7EcIjbCr0wThpi
    tasty-1.5.4-GkivOVRJs7F6rF5OuEyJnC
    tasty-expected-failure-0.12.3-8vSmIUZWy85L5DtInL8JIo
    tasty-golden-2.3.6-Hd0p8uqdQvyLTZN627NXNx
    tasty-hunit-0.10.2-IyGMLJQ0P1qA3GfBVc1Boi
    tasty-rerun-1.1.20-AhboNBQmSWy5z9n01x6V2a
    temporary-1.3-6LHFZ2D4FfEKQZFjyV7a7h text-2.0.2
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt

haddock-interfaces:
    /usr/share/doc/haskell-hls-test-utils/html/hls-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-hls-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

